A Gno.Store.Adapter implementation for Oxigraph.
Manifest Configuration
@prefix gno: <http://gno.app/> .
@prefix gnoa: <http://gno.app/ns/adapter/> .
<Oxigraph> a gnoa:Oxigraph
; gno:storeEndpointScheme "http" # optional (default: "http")
; gno:storeEndpointHost "localhost" # optional (default: "localhost")
; gno:storeEndpointPort 7878 # optional (default: 7878)
.
Summary
Functions
Returns the graph semantics for a specific adapter instance.
Types
Functions
@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}
@spec from!(Grax.Schema.t()) :: t()
Returns the graph semantics for a specific adapter instance.
Checks the default_graph_semantics_config manifest property first,
falling back to default_graph_semantics/0.
@spec load( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: {:ok, t()} | {:error, any()}
@spec load!( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: t()