Base Grax schema for triple stores hosting a DCATR.Repository.
Concrete store types are defined by Gno.Store.Adapter implementations
(e.g. Gno.Store.Adapters.Fuseki). This module provides generic endpoint
resolution and delegates SPARQL operations to the appropriate adapter.
It can also be used directly as a generic adapter for any SPARQL 1.1 protocol-compliant triple store that has no dedicated adapter implementation:
@prefix gno: <http://gno.app/> .
<MyStore> a gno:Store
; gno:storeQueryEndpoint <http://localhost:7878/query> # required
; gno:storeUpdateEndpoint <http://localhost:7878/update> # optional
; gno:storeGraphStoreEndpoint <http://localhost:7878/store> # optional
.
Summary
Functions
Returns the list of known store adapter class IRIs.
Returns the list of available store adapter modules.
Returns the base endpoint URL for the store.
Returns the base endpoint URL with the given path appended.
Returns the SPARQL Graph Store Protocol endpoint URL for the store.
Returns the SPARQL query endpoint URL for the store.
Returns the SPARQL update endpoint URL for the store.
Types
Functions
Returns the list of known store adapter class IRIs.
Returns the list of available store adapter modules.
Returns the base endpoint URL for the store.
Constructed from the store's scheme, host, port, and dataset properties.
Returns {:error, ...} if the required properties are missing.
Returns the base endpoint URL with the given path appended.
@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}
@spec from!(Grax.Schema.t()) :: t()
Returns the SPARQL Graph Store Protocol endpoint URL for the store.
@spec load( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: {:ok, t()} | {:error, any()}
@spec load!( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: t()
Returns the SPARQL query endpoint URL for the store.
Uses the explicitly configured query_endpoint if set, otherwise
delegates to the adapter's Gno.Store.Adapter.determine_query_endpoint/1.
Returns the SPARQL update endpoint URL for the store.